summaryrefslogtreecommitdiff
path: root/scripts/travis_prepare.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/travis_prepare.sh')
-rwxr-xr-xscripts/travis_prepare.sh26
1 files changed, 17 insertions, 9 deletions
diff --git a/scripts/travis_prepare.sh b/scripts/travis_prepare.sh
index 1e18593..068285c 100755
--- a/scripts/travis_prepare.sh
+++ b/scripts/travis_prepare.sh
@@ -13,6 +13,11 @@ set -e -x
#
# The variables can be set in the travis configuration
# (https://travis-ci.org/psycopg/psycopg2/settings)
+export TEST_PAST=${TEST_PAST:-0}
+export TEST_FUTURE=${TEST_FUTURE:-0}
+export TEST_VERBOSE=${TEST_VERBOSE:-0}
+export PSYCOPG2_TEST_FAST=${PSYCOPG2_TEST_FAST:-0}
+export TEST_PRESENT=${TEST_PRESENT:-1}
set_param () {
# Set a parameter in a postgresql.conf file
@@ -115,16 +120,19 @@ create () {
# Would give a permission denied error in the travis build dir
cd /
-# Postgres versions supported by Travis CI
-if (( ! "$DONT_TEST_PRESENT" )); then
- create 12
- create 11
- create 10
- create 9.6
- create 9.5
- create 9.4
+if (( "$TEST_PRESENT" )); then
+ if [[ ${TRAVIS_CPU_ARCH} == "arm64" ]]; then
+ # Postgres versions supported by ARM64
+ create 10
+ else
+ create 12
+ create 11
+ create 10
+ create 9.6
+ create 9.5
+ create 9.4
+ fi
fi
-
# Unsupported postgres versions that we still support
# Images built by https://github.com/psycopg/psycopg2-wheels/tree/build-dinosaurs
if (( "$TEST_PAST" )); then